% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The MicroFlu10 LaTeX Document Class %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{microflu12pdf}[2012/04/13 Version 1.00 
                         MicroFlu12 LaTeX Document Class]

% Document options

% Paper sizes
\DeclareOption{a4paper}
   {\setlength\paperheight {297mm}%
    \setlength\paperwidth  {210mm}}

% Type area sizes
\DeclareOption{microflupage}
   {\setlength\textwidth  {170mm}%
    \setlength\textheight {255mm}}

% Support these LaTeX options
\DeclareOption{draft}{\setlength\overfullrule{5pt}}%
\DeclareOption{final}{\setlength\overfullrule{0pt}}

\ExecuteOptions{a4paper,microflupage,final}
\ProcessOptions\relax

% Load all necessary packages
\RequirePackage{latexsym}
\RequirePackage{times}
\RequirePackage{amsmath,amssymb,amsfonts}
\RequirePackage[pdftex]{graphicx}
\RequirePackage{epstopdf}
\RequirePackage{fancyhdr}

\def\bfdefault{b}

% Not sure if needed.
\newcommand\@ptsize{0}

%
% Set page layout dimensions
%
%\setlength\headheight{\z@}          % no running head
%\setlength\headsep{\z@}             % space below running head --
\setlength\topskip{10\p@}           % height of first line of text
\setlength\headheight{15\p@}        % head height
\setlength\headsep{3mm}             % space below running head --

%\setlength\footskip{\z@}            % space above footer line
\setlength\footskip{17mm}           
\setlength\maxdepth{.5\topskip}     % pages can be short or deep by half a line?

% Set the margins
\setlength\oddsidemargin   {20mm}
\setlength\topmargin       {11mm}
\addtolength\oddsidemargin {-1in}
\addtolength\topmargin     {-1in}

% Default font sizes
\renewcommand\normalsize{%
%   \@setfontsize\normalsize\@xipt{13.6}%
   \@setfontsize\normalsize\@xipt{13}%
   \abovedisplayskip 11\p@ \@plus3\p@ \@minus6\p@
   \abovedisplayshortskip \z@ \@plus3\p@
   \belowdisplayshortskip 6.5\p@ \@plus3.5\p@ \@minus3\p@
   \belowdisplayskip \abovedisplayskip
   \let\@listi\@listI}
\normalsize
\let\@bls\baselineskip

\newcommand\small{%
%   \@setfontsize\small\@xpt\@xiipt
%   \@setfontsize\small\@xpt\@xipt
   \@setfontsize\small\@xpt{11.5}
   \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
   \abovedisplayshortskip \z@ \@plus3\p@
   \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 6\p@ \@plus2\p@ \@minus2\p@
               \parsep 3\p@ \@plus2\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}
\newcommand\footnotesize{%
   \@setfontsize\footnotesize\@ixpt{11}%
   \abovedisplayskip 8\p@ \@plus2\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus\p@
   \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 4\p@ \@plus2\p@ \@minus2\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}
\newcommand\scriptsize{\@setfontsize\scriptsize\@viiipt{9.5}}
\newcommand\tiny{\@setfontsize\tiny\@vipt\@viipt}
\newcommand\large{\@setfontsize\large\@xiipt{14}}
\newcommand\Large{\@setfontsize\Large\@xivpt{18}}
\newcommand\LARGE{\@setfontsize\LARGE\@xviipt{22}}
\newcommand\huge{\@setfontsize\huge\@xxpt{25}}
\newcommand\Huge{\@setfontsize\Huge\@xxvpt{30}}

\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}

% Line spacing
\setlength\lineskip{1\p@}
\setlength\normallineskip{1\p@}
\renewcommand\baselinestretch{}

% Paragraph dimensions and inter-para spacing
\setlength\parskip{0\p@}
\setlength\parindent{0\p@}

% Set inter-para skips
\setlength\smallskipamount{3\p@ \@plus 1\p@ \@minus 1\p@}
\setlength\medskipamount{6\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\bigskipamount{12\p@ \@plus 4\p@ \@minus 4\p@}

% Page break penalties
\@lowpenalty   51
\@medpenalty  151
\@highpenalty 301

% Disallow widows and orphans
\widowpenalty=9999              
\clubpenalty=9999               

% Disable page breaks before equations, allow pagebreaks after
% equations and discourage widow lines before equations.
\displaywidowpenalty 1000
\predisplaypenalty   10000
\postdisplaypenalty  1500

% Allow breaking the page in the middle of a paragraph
\interlinepenalty 0

% Hyphenation; don't split words into less than three characters
% No consecutive hyphens, disallow breaking the page after 
% a hyphenated line
\lefthyphenmin=3
\righthyphenmin=3
\doublehyphendemerits=10000
\brokenpenalty 7000

% Don't allow footnotes to split over pages
\interfootnotelinepenalty=9999  

\setlength\columnsep{12\p@}         % space between columns for double-column text
\setlength\columnseprule{0\p@}      % width of rule between two columns

% Footnotes

%\setlength\footnotesep{6.65\p@}     % space between footnotes
\setlength\footnotesep{9\p@}     % space between footnotes
% space between text and footnote
\setlength{\skip\footins}{22\p@ \@plus 4\p@ \@minus 2\p@}

% Float placement parameters

% The total number of floats that can be allowed on a page.
\setcounter{totalnumber}{10}
% The maximum number of floats at the top and bottom of a page.
\setcounter{topnumber}{5}
\setcounter{bottomnumber}{5}
% The maximum part of the top or bottom of a text page that can be
% occupied by floats. This is set so that at least four lines of text 
% fit on the page.
\renewcommand\topfraction{.9}
\renewcommand\bottomfraction{.9}
% The minimum amount of a text page that must be occupied by text.
% This should accomodate four lines of text.
\renewcommand\textfraction{.06}
% The minimum amount of a float page that must be occupied by floats.
\renewcommand\floatpagefraction{.94}

% The same parameters repeated for double column output
\renewcommand\dbltopfraction{.9}
\renewcommand\dblfloatpagefraction{.9}

% Space between floats
\setlength\floatsep    {12\p@ \@plus 2\p@ \@minus 2\p@}
% Space between floats and text
\setlength\textfloatsep{20\p@ \@plus 2\p@ \@minus 4\p@}
% Space above and below an inline figure
\setlength\intextsep   {18\p@ \@plus 2\p@ \@minus 2\p@}

% Space left at top, bottom and inbetween floats on a float page.
\setlength\@fptop{0\p@}         % no space above float page figures
\setlength\@fpsep{12\p@ \@plus 1fil}
\setlength\@fpbot{0\p@ \@plus 1fil}

% Sectional units

% Lowest level heading that takes a number by default
\setcounter{secnumdepth}{4}
    
% Counters
\newcounter{section}
\newcounter{subsection}[section]
\newcounter{subsubsection}[subsection]
\newcounter{paragraph}[subsubsection]
\newcounter{subparagraph}[paragraph]
\newcounter{figure}
\newcounter{table}

% Form of the numbers
\newcommand\thepage{\arabic{page}}
\renewcommand\thesection{\arabic{section}.}
\renewcommand\thesubsection{{\thesection\arabic{subsection}}}
\renewcommand\thesubsubsection{{\thesubsection.\arabic{subsubsection}}}
\renewcommand\theparagraph{\thesubsubsection.\arabic{paragraph}}
\renewcommand\thesubparagraph{\theparagraph.\arabic{subparagraph}}
\renewcommand\theequation{\arabic{equation}}

%\newcommand\appendixname{APPENDIX}
%\newcommand\abstractname{ASTRACT}
%\newcommand\refname{REFERENCES AND CITATIONS}
\newcommand\figurename{Figure}
\newcommand\tablename{Table}

% Add confpaper
\def\confpaper#1{\gdef\@confpaper{#1}}

\newcommand\maketitle{\par
  \begingroup
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
%    \thispagestyle{empty}\@thanks
    \thispagestyle{fancy}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@confpaper\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\def\@maketitle{%
  \newpage
  \begingroup
  \parindent\z@
  \let \footnote \thanks
  \vspace*{10pt}%
    {\fontsize{14}{18}\selectfont\bfseries\raggedleft \@confpaper \par}%
  \begin{center}
  \vspace*{33pt}%
    {\fontsize{14}{18}\selectfont\bfseries\@title \par}%
    \vspace{11pt}
    {\fontsize{11}{13}\selectfont \@author \par}%
  \end{center}
  \vspace{11pt}%
  \endgroup}

%% Abstract
%\newenvironment{abstract}{{\noindent\large\bfseries\abstractname}\par\vspace{12pt}%
%    \normalfont\normalsize\noindent\ignorespaces
%}{}

% Text headings

\renewcommand{\@seccntformat}[1]{{\csname the#1\endcsname}\enskip}

\def\section{%
  \@startsection{section}{1}{\z@}
%  {-1\@bls plus -1\p@}{1\@bls}
  {-22\p@ plus -1\p@}{11\p@}
  {\reset@font\normalfont\large\bfseries\raggedright}}
    
\def\subsection{%
  \@startsection{subsection}{2}{\z@}
%  {-1\@bls plus -1\p@}{1\@bls}
  {-11\p@ plus -1\p@}{11\p@}
  {\reset@font\normalfont\normalsize\bfseries\raggedright}}
   
\def\subsubsection{%
  \@startsection{subsubsection}{3}{\z@}
%  {-1\@bls plus -1\p@}{1sp}
  {-6\p@ plus -1\p@}{6\p@}
  {\reset@font\normalfont\normalsize\itshape\raggedright}}

\def\paragraph{%
  \@startsection{paragraph}{4}{\z@}
  {-1\@bls plus -1\p@}{-1em}
  {\reset@font\normalfont\normalsize\bfseries}}

% Figures and Tables and captions

\newlength{\abovecaptionskip}
\newlength{\belowcaptionskip}
\setlength{\abovecaptionskip}{7pt}
\setlength{\belowcaptionskip}{11pt}

\long\def\@caption#1[#2]#3{\addcontentsline{\csname ext@#1\endcsname}{#1}
        {\protect\numberline{\csname fnum@#1\endcsname}
        {\ignorespaces #2}}
        \begingroup
        \@parboxrestore
        \@makecaption{\csname fnum@#1\endcsname}{#3}\par
        \endgroup}

\newbox\@tempboxb
\newdimen\@captionwidth
\newdimen\@narrow
\setlength\@narrow{7mm}
\setlength\@captionwidth{\textwidth}
\addtolength\@captionwidth{-2\@narrow}%

\long\def\@makecaption#1#2{\vspace{\abovecaptionskip}
        \setbox\@tempboxa\hbox{\small{\textbf{#1}:}\ #2\strut}%
        \ifdim \wd\@tempboxa > \@captionwidth \par
                \hspace{\@narrow}\parbox[c]{\@captionwidth}{\small\textbf{#1}:\ #2}
        \else
                \hbox to\hsize{\hfil\box\@tempboxa\hfil}
        \fi\vspace{\belowcaptionskip}}

\long\def\@tablecaption#1#2{\vspace{\belowcaptionskip}%
        \setbox\@tempboxa\hbox{\small{\textbf{#1}:}\ #2\strut}%
        \ifdim \wd\@tempboxa > \@captionwidth \par
                \hspace{\@narrow}\parbox[c]{\@captionwidth}{\small\textbf{#1}:\ #2}
        \else
                \hbox to\hsize{\hfil\box\@tempboxa\hfil}
        \fi\vspace{\belowcaptionskip}}

\def\thefigure{\@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{\figurename~\thefigure}
\def\figure{\@float{figure}}
\let\endfigure\end@float
\@namedef{figure*}{\@dblfloat{figure}}
\@namedef{endfigure*}{\end@dblfloat}
\def\thetable{\@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{\tablename~\thetable}
\def\table{\let\@makecaption\@tablecaption\@float{table}}
\let\endtable\end@float
\@namedef{table*}{\let\@makecaption\@tablecaption\@dblfloat{table}}
\@namedef{endtable*}{\end@dblfloat}

% Lists - as in article.cls

\setlength\leftmargini  {2.5em}

\leftmargin  \leftmargini
\setlength\leftmarginii  {2.2em}
\setlength\leftmarginiii {1.87em}
\setlength\leftmarginiv  {1.7em}
\setlength\leftmarginv  {1em}
\setlength\leftmarginvi {1em}
\setlength  \labelsep  {.3em}
\setlength  \labelwidth{\leftmargini}
\addtolength\labelwidth{-\labelsep}

\renewcommand\theenumi{\@arabic\c@enumi}
\renewcommand\theenumii{\@alph\c@enumii}
\renewcommand\theenumiii{\@roman\c@enumiii}
\renewcommand\theenumiv{\@Alph\c@enumiv}
\newcommand\labelenumi{\theenumi.}
\newcommand\labelenumii{(\theenumii)}
\newcommand\labelenumiii{\theenumiii.}
\newcommand\labelenumiv{\theenumiv.}
\renewcommand\p@enumii{\theenumi}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\renewcommand\p@enumiv{\p@enumiii\theenumiii}
\newcommand\labelitemi{\textbullet}
\newcommand\labelitemii{\normalfont\bfseries \textendash}
\newcommand\labelitemiii{\textasteriskcentered}
\newcommand\labelitemiv{\textperiodcentered}

\newenvironment{description}
               {\list{}{\topsep\bigskipamount\labelwidth\z@ \itemindent-\leftmargin
                        \let\makelabel\descriptionlabel}}
               {\endlist}
\newcommand*\descriptionlabel[1]{\hspace\labelsep
                                \normalfont\bfseries #1}

% Verse, quotation, and quote environments. 
% The same as in article.cls

\newenvironment{verse}
               {\let\\\@centercr
                \list{}{\itemsep      \z@
                        \itemindent   -1.5em%
                        \listparindent\itemindent
                        \rightmargin  \leftmargin
                        \advance\leftmargin 1.5em}%
                \item\relax}
               {\endlist}
\newenvironment{quotation}
               {\list{}{\listparindent 1.5em%
                        \itemindent    \listparindent
                        \rightmargin   \leftmargin
                        \parsep        \z@ \@plus\p@}%
                \item\relax}
               {\endlist}
\newenvironment{quote}
               {\list{}{\rightmargin\leftmargin}%
                \item\relax}
               {\endlist}

% Bibligraphy

\newenvironment{thebibliography}[1]
     {%\section*{\refname}%
      %\@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
\newcommand\newblock{}
\let\@openbib@code\@empty
      
% Footnotes

\renewcommand\footnoterule{%
  \kern-3\p@
  \hrule\@width 0.3\columnwidth
  \kern2.6\p@}
\newcommand\@makefntext[1]{%
    \noindent
    \hb@xt@0.3em{\small\hss\@makefnmark}\small#1}

% Appendix

%\def\appendix{\par
%        \setcounter{section}{0}
%        \setcounter{subsection}{0}
%        \appendtrue}
      
% Math parameters

\setlength{\jot}{5\p@} 

% Reset eqnarray to avoid \arraycolsep between 
% columns. Take from a post on comp.text.tex 
% by Fred Bartlett <fbartlet@optonline.net> 
\newif\if@alignpoint
\def\eqnarray{%
  \stepcounter{equation}%
  \def\@currentlabel{\p@equation\theequation}%
  \global\@eqnswtrue
  \m@th
  \global\@eqcnt\z@
  \tabskip\@centering
  \let\\\@eqncr
  $$\everycr{}\halign to\displaywidth\bgroup
    \hskip\@centering$\displaystyle\tabskip\z@skip{##}$\@eqnsel
  &\global\@eqcnt\@ne\hfil\setbox\z@\hbox{$\displaystyle{{}##{}}$}%
    \global\ifdim\wd\z@>\z@\@alignpointtrue\else\@alignpointfalse\fi
    \box\z@\hfil
  &\global\@eqcnt\tw@$\displaystyle{\if@alignpoint\else{}\fi##}$\hfil
    \tabskip\@centering
  &\global\@eqcnt\thr@@ \hb@xt@\z@\bgroup\hss##\egroup
         \tabskip\z@skip
  \cr}

% Table, array and box values
\setlength\arraycolsep{.5em}
\setlength\tabcolsep{.5em}
\setlength\arrayrulewidth{.4pt}
\setlength\doublerulesep{2pt}
\renewcommand\arraystretch{1.25}
\setlength\tabbingsep{\labelsep}
\skip\@mpfootins = \skip\footins
\setlength\fboxsep{3\p@}
\setlength\fboxrule{.4\p@}

\flushbottom
\frenchspacing
\ps@empty
\onecolumn

% Heading and footer

\pagenumbering{arabic}
\pagestyle{fancy}
\lhead{}
\chead{}
\rhead{\footnotesize\textit{Proceedings of the 3$^{rd}$ European Conference on Microfluidics - Microfluidics 2012 - Heidelberg, December 3-5, 2012}}
\lfoot{}
\cfoot{\thepage}
\rfoot{\raisebox{1.5pt}{\footnotesize\copyright} SHF 2012}

% Other microFLU08 settings

\newcommand{\confname}{\mbox{\boldmath$\mu$}FLU12}
\newcommand{\abstractstyle}[1]{\parbox{\textwidth}{\vspace{5pt}\small\itshape#1}}
\newcommand{\parind}{\vspace{\baselineskip}\hspace{7.5mm}}

\newcommand{\corrauth}{%
\renewcommand{\thefootnote}{\fnsymbol{footnote}}%
\footnotemark\footnotetext{Corresponding author}%
}

\newcommand{\bfsup}[1]{\mbox{\boldmath{$^{#1}$}}}%

\endinput
% End of file microflu10.cls
